@@ -7,7 +7,7 @@ use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Base';
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 has marc_path      => (fix_arg => 1);
 has path           => (fix_arg => 1);
@@ -20,6 +20,7 @@ has nested_arrays  => (fix_opt => 1);
 sub emit {
     my ($self,$fixer) = @_;
     my $path         = $fixer->split_path($self->path);
+    my $key          = $path->[-1];
     my $marc_obj     = Catmandu::MARC->instance;
 
     # Precompile the marc_path to gain some speed
@@ -27,31 +28,40 @@ sub emit {
     my $marc         = $fixer->capture($marc_obj);
     my $marc_path    = $fixer->capture($marc_context);
     my $marc_opt     = $fixer->capture({
-                            '-join'   => $self->join   // '' ,
-                            '-split'  => $self->split  // 0 ,
-                            '-pluck'  => $self->pluck  // 0 ,
+                            '-join'       => $self->join   // '' ,
+                            '-split'      => $self->split  // 0 ,
+                            '-pluck'      => $self->pluck  // 0 ,
                             '-nested_arrays' => $self->nested_arrays // 0 ,
-                            '-value'  => $self->value
+                            '-value'      => $self->value ,
+                            '-append'     => $key eq '$append'
                         });
-    my $var          = $fixer->var;
-    my $result       = $fixer->generate_var;
 
-    my $perl =<<EOF;
+    my $var           = $fixer->var;
+    my $result        = $fixer->generate_var;
+    my $current_value = $fixer->generate_var;
+
+    my $perl = "";
+    $perl .= $fixer->emit_declare_vars($current_value, "[]");
+    $perl .=<<EOF;
 if (my ${result} = ${marc}->marc_map(
             ${var},
             ${marc_path},
             ${marc_opt}) ) {
+    ${result} = ref(${result}) ? ${result} : [${result}];
+    for ${current_value} (\@{${result}}) {
 EOF
+
     $perl .= $fixer->emit_create_path(
             $var,
             $path,
             sub {
                 my $var2 = shift;
-                "${var2} = ${result}"
+                "${var2} = ${current_value}"
             }
     );
 
     $perl .=<<EOF;
+    }
 }
 EOF
     $perl;
@@ -102,7 +112,7 @@ Catmandu::Fix::marc_map - copy marc values of one field to a new field
     marc_map('100^0123456789','author')
 
     # Map all the 500 - 599 fields to my.notes
-    marc_map('5**','my.motes')
+    marc_map('5..','my.motes')
 
     # Map the 100-a field where indicator-1 is 3
     marc_map('100[3]a','name.family')
@@ -137,10 +147,14 @@ The MARC_PATH can point to one or more MARC subfields. For instamce:
     marc_path('245a',title)
     marc_path('245ac',title)
 
+You can also use dollar signs to indicate subfields
+
+    marc_path('245$a$c',title)
+
 Wildcards are allowed in the field names:
 
     # Map all the 200-fields to a title
-    marc_map('2**'',title)
+    marc_map('2..'',title)
 
 To filter out specific fields indicators can be used:
 
@@ -155,6 +169,9 @@ Also a substring of a field value can be mapped:
 By default all matched fields in a MARC_PATH will be joined into one string.
 This behavior can be changed using one more more options (see below).
 
+Visit our Wiki L<https://github.com/LibreCat/Catmandu-MARC/wiki/Mapping-rules>
+for a complete overview of all allowed mappings.
+
 =head1 OPTIONS
 
 =head2 split: 0|1
