@@ -13,7 +13,7 @@ memoize('compile_marc_path');
 memoize('parse_marc_spec');
 memoize('get_index_range');
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 sub marc_map {
     my $self      = $_[0];
@@ -36,6 +36,7 @@ sub marc_map {
     my $pluck          = $_[3]->{'-pluck'} // 0;
     my $value_set      = $_[3]->{'-value'} // undef;
     my $nested_arrays  = $_[3]->{'-nested_arrays'} // 0;
+    my $append         = $_[3]->{'-append'} // undef;
 
     my $vals;
 
@@ -134,16 +135,24 @@ sub marc_map {
                 }
             }
             else {
-                if (defined($vals) && ref($vals) eq '') {
-                    $vals = join $join_char , $vals , $v;
-                }
-                else {
-                    $vals = $v;
-                }
+                push @$vals , $v;
             }
         }
     }
 
+    if ($split) {
+        $vals = [ $vals ];
+    }
+    elsif ($append) {
+        # we got a $append
+    }
+    elsif (defined $vals) {
+        $vals = join $join_char , @$vals;
+    }
+    else {
+        # no result
+    }
+
     $vals;
 }
 
@@ -341,6 +350,7 @@ sub marc_spec {
     my $pluck          = $_[3]->{'-pluck'} // 0;
     my $value_set      = $_[3]->{'-value'} // undef;
     my $invert         = $_[3]->{'-invert'} // 0;
+    my $append         = $_[3]->{'-append'} // undef;
 
     my $vals;
 
@@ -426,6 +436,9 @@ sub marc_spec {
 
         for my $field (@fields) {
             my $start = 3;
+
+            my @sf_results;
+
             for my $sf (@sf_spec) {
                 # set invert level
                 if ( $invert ) {
@@ -457,10 +470,10 @@ sub marc_spec {
                 }
 
                 if ( $invert_level == 3 ) {
-                    if (@subfield) { push @subfields, @subfield }
+                    if (@subfield) { push @sf_results, @subfield }
 
                     # return $value_set ASAP
-                    if ( @subfields && $value_set ) {
+                    if ( @sf_results && $value_set ) {
                         return $value_set;
                     }
                     next;
@@ -506,17 +519,35 @@ sub marc_spec {
                           @subfield;
                     }
                 }
-                push @subfields, @subfield if (@subfield);
+
+                push @sf_results, @subfield;
+            }
+
+            if ($split) {
+                push @subfields, @sf_results;
+            }
+            else {
+                push @subfields, join($join_char,@sf_results);
             }
         }
 
         unless (@subfields) { return $vals }
 
-        $vals = ($split)
-          ? [@subfields]
-          : join( $join_char, @subfields );
+        if ($split) {
+            $vals = [[@subfields]];
+        }
+        elsif ($append) {
+            $vals = [@subfields];
+        }
+        elsif (@subfields) {
+            $vals = join( $join_char, @subfields );
+        }
+        else {
+            $vals = undef;
+        }
     }
     else {    # no particular subfields requested
+
         my $char_start = $field_spec->char_start;
         if ( defined $char_start ) {
             $char_start =
@@ -524,6 +555,7 @@ sub marc_spec {
               ? $field_spec->char_length * -1
               : $char_start;
         }
+
         my @mapped = ();
         for my $field (@fields) {
             my $start = 4;
@@ -540,14 +572,33 @@ sub marc_spec {
                   map { substr $_, $char_start, $field_spec->char_length }
                     @subfields;
             }
-            push @mapped, @subfields;
-        }
-        unless (@mapped) { return $vals }
 
-        $vals = ($split)
-          ? [@mapped]
-          : join $join_char, @mapped;
+            if ($split) {
+                push @mapped, @subfields;
+            }
+            else {
+                push @mapped, join($join_char,@subfields);
+            }
+        }
+
+        unless (@mapped) {
+            return $vals
+        }
+
+        if ($split) {
+            $vals = [[@mapped]];
+        }
+        elsif ($append) {
+            $vals = [ @mapped ];
+        }
+        elsif (@mapped) {
+            $vals = join $join_char, @mapped;
+        }
+        else {
+            $vals = undef;
+        }
     }
+
     return $vals;
 }
 
@@ -718,7 +769,7 @@ sub compile_marc_path {
     my ($field,$field_regex,$ind1,$ind2,
         $subfield,$subfield_regex,$from,$to,$len,$is_regex_field);
 
-    my $MARC_PATH_REGEX = qr/(\S{1,3})(\[([^,])?,?([^,])?\])?([_a-z0-9^]+)?(\/(\d+)(-(\d+))?)?/;
+    my $MARC_PATH_REGEX = qr/(\S{1,3})(\[([^,])?,?([^,])?\])?([\$_a-z0-9^]+)?(\/(\d+)(-(\d+))?)?/;
     if ($marc_path =~ $MARC_PATH_REGEX) {
         $field          = $1;
         $ind1           = $3;
@@ -726,6 +777,7 @@ sub compile_marc_path {
         $subfield       = $5;
         $field = "0" x (3 - length($field)) . $field; # fixing 020 treated as 20 bug
         if (defined($subfield)) {
+            $subfield =~ s{\$}{}g;
             unless ($subfield =~ /^[a-zA-Z0-9]$/) {
                 $subfield = "[$subfield]";
             }
@@ -747,9 +799,9 @@ sub compile_marc_path {
         return undef;
     }
 
-    if ($field =~ /\*/) {
+    if ($field =~ /[\*\.]/) {
         $field_regex    = $field;
-        $field_regex    =~ s/\*/(?:[A-Z0-9])/g;
+        $field_regex    =~ s/[\*\.]/(?:[A-Z0-9])/g;
         $is_regex_field = 1;
         $field_regex    = qr/^$field_regex$/;
     }
